==> sghi_core-0.2.38.tar.gz: test/afya_moja_core/selection_option_field_test.dart <==
// Flutter imports
import 'package:flutter/material.dart';
// Package imports
import 'package:flutter_test/flutter_test.dart';
import 'package:sghi_core/afya_moja_core/afya_moja_core.dart';

void main() {
  group('SelectOptionField', () {
    testWidgets('SelectOptionField', (WidgetTester tester) async {
      Type typeOf<T>() {
        return T;
      }

      const Key selectOptionFieldKey = Key('select_option_field');
      const String selectedGender = 'Male';
      const Key formKey = Key('select_option_field');
      final List<String> options = <String>[
        'Male',
        'Female',
        'Unknown',
        'Other'
      ];

      await tester.pumpWidget(
        MaterialApp(
          home: Builder(
            builder: (BuildContext context) {
              return Scaffold(
                body: Form(
                  key: formKey,
                  child: SelectOptionField(
                    dropDownInputKey: selectOptionFieldKey,
                    hintText: 'Select gender',
                    value: selectedGender,
                    options: options,
                    onSaved: (dynamic value) {},
                    onChanged: (dynamic val) {},
                  ),
                ),
              );
            },
          ),
        ),
      );

      expect(find.byKey(formKey), findsWidgets);

      expect(find.byKey(selectOptionFieldKey), findsWidgets);
      expect(find.byType(DropdownButtonHideUnderline), findsOneWidget);
      expect(find.byType(typeOf<DropdownButton<String>>()), findsOneWidget);

      await tester.tap(find.text('Select gender'));
      await tester.pumpAndSettle();
      await tester.tap(find.text('Female').last);
      await tester.pumpAndSettle();
    });
  });
}

==> sghi_core-0.3.56.tar.gz: test/afya_moja_core/selection_option_field_test.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:sghi_core/afya_moja_core/afya_moja_core.dart';

void main() {
  group('SelectOptionField', () {
    testWidgets('SelectOptionField', (WidgetTester tester) async {
      Type typeOf<T>() => T;

      const Key selectOptionFieldKey = Key('select_option_field');
      const String selectedGender = 'Male';
      const Key formKey = Key('select_option_field');
      final List<String> options = <String>[
        'Male',
        'Female',
        'Unknown',
        'Other'
      ];

      await tester.pumpWidget(
        MaterialApp(
          home: Builder(
            builder: (BuildContext context) {
              return Scaffold(
                body: Form(
                  key: formKey,
                  child: SelectOptionField(
                    dropDownInputKey: selectOptionFieldKey,
                    hintText: 'Select gender',
                    value: selectedGender,
                    options: options,
                    onSaved: (dynamic value) {},
                    onChanged: (dynamic val) {},
                  ),
                ),
              );
            },
          ),
        ),
      );
      await tester.pumpAndSettle();

      expect(find.byKey(formKey), findsWidgets);

      expect(find.byKey(selectOptionFieldKey), findsWidgets);
      expect(find.byType(DropdownButtonHideUnderline), findsOneWidget);
      expect(find.byType(typeOf<DropdownButton<String>>()), findsOneWidget);

      await tester.tap(find.byKey(selectOptionFieldKey).first);
      await tester.pumpAndSettle();
      await tester.tap(find.text('Female').last);
      await tester.pumpAndSettle();
    });
  });
}
